# Generated by roxygen2: do not edit by hand

export(ERSex)
export(ERSin)
export(FCSc_mean)
export(FCSex)
export(FCSin)
export(GRSex)
export(GRSin)
export(SRSex)
export(SRSin)
export(checkEcoregion)
export(checkOccurrences)
export(checkProtectedAreas)
export(checksdm)
export(generateCounts)
export(generateEcoSelection)
export(generateGBuffers)
export(getDatasets)
importFrom(dataverse,get_file)
importFrom(dplyr,case_when)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,pull)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize)
importFrom(dplyr,tibble)
importFrom(leaflet,addCircleMarkers)
importFrom(leaflet,addControl)
importFrom(leaflet,addLegend)
importFrom(leaflet,addPolygons)
importFrom(leaflet,addRasterImage)
importFrom(leaflet,addTiles)
importFrom(leaflet,leaflet)
importFrom(terra,aggregate)
importFrom(terra,as.data.frame)
importFrom(terra,buffer)
importFrom(terra,cellSize)
importFrom(terra,crop)
importFrom(terra,crs)
importFrom(terra,expanse)
importFrom(terra,extract)
importFrom(terra,intersect)
importFrom(terra,mask)
importFrom(terra,project)
importFrom(terra,rast)
importFrom(terra,rasterize)
importFrom(terra,res)
importFrom(terra,same.crs)
importFrom(terra,values)
importFrom(terra,vect)
importFrom(terra,writeRaster)
importFrom(terra,zonal)
