% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{CucurbitaRasters}
\alias{CucurbitaRasters}
\alias{CucurbitaRasts}
\title{Cucurbita species distribution models dataset}
\format{
terra rast object stored as a PackedSpatRaster
}
\source{
\doi{10.7910/DVN/B8YOQL}
}
\usage{
CucurbitaRasts
}
\description{
This dataset is a subset of species distribution models for:
 C. cordata, C. digitata and C. palmata used in Khoury et al., 2020
}
\references{
Khoury et al. (2019) Diversity and Distributions 26(2):209-225. \doi{10.1111/DDI.13008}
}
\keyword{datasets}
